==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/dbformysql/kotlin/outputs/GetFirewallRuleResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbformysql.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Represents a server firewall rule.
 * @property endIpAddress The end IP address of the server firewall rule. Must be IPv4 format.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property name The name of the resource
 * @property startIpAddress The start IP address of the server firewall rule. Must be IPv4 format.
 * @property systemData The system metadata relating to this resource.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetFirewallRuleResult(
    public val endIpAddress: String,
    public val id: String,
    public val name: String,
    public val startIpAddress: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.dbformysql.outputs.GetFirewallRuleResult):
            GetFirewallRuleResult = GetFirewallRuleResult(
            endIpAddress = javaType.endIpAddress(),
            id = javaType.id(),
            name = javaType.name(),
            startIpAddress = javaType.startIpAddress(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.dbformysql.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/dbformysql/kotlin/outputs/GetFirewallRuleResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbformysql.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Represents a server firewall rule.
 * @property endIpAddress The end IP address of the server firewall rule. Must be IPv4 format.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property name The name of the resource
 * @property startIpAddress The start IP address of the server firewall rule. Must be IPv4 format.
 * @property systemData The system metadata relating to this resource.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetFirewallRuleResult(
    public val endIpAddress: String,
    public val id: String,
    public val name: String,
    public val startIpAddress: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.dbformysql.outputs.GetFirewallRuleResult): GetFirewallRuleResult = GetFirewallRuleResult(
            endIpAddress = javaType.endIpAddress(),
            id = javaType.id(),
            name = javaType.name(),
            startIpAddress = javaType.startIpAddress(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.dbformysql.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}
